cgexplore.molecular.Precursor
=============================

.. currentmodule:: cgexplore.molecular

.. autoclass:: Precursor
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Precursor.get_bead_set
      ~Precursor.get_building_block
      ~Precursor.get_name
   
   

   
   
   